summaryrefslogtreecommitdiffstats
path: root/chrome/browser/chromeos/cros/input_method_library.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/chromeos/cros/input_method_library.h')
-rw-r--r--chrome/browser/chromeos/cros/input_method_library.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/browser/chromeos/cros/input_method_library.h b/chrome/browser/chromeos/cros/input_method_library.h
index 26df7a7..07b07ef 100644
--- a/chrome/browser/chromeos/cros/input_method_library.h
+++ b/chrome/browser/chromeos/cros/input_method_library.h
@@ -106,11 +106,11 @@ class InputMethodLibrary {
virtual std::string GetKeyboardOverlayId(
const std::string& input_method_id) = 0;
- // Sets the IME state to enabled, and launches its processes if needed.
- virtual void StartInputMethodProcesses() = 0;
+ // Sets the IME state to enabled, and launches input method daemon if needed.
+ virtual void StartInputMethodDaemon() = 0;
- // Disables the IME, and kills the processes if they are running.
- virtual void StopInputMethodProcesses() = 0;
+ // Disables the IME, and kills the daemon process if they are running.
+ virtual void StopInputMethodDaemon() = 0;
// Controls whether the IME process is started when preload engines are
// specificed, or defered until a non-default method is activated.